@@ -1,4 +1,4 @@
-__version__ = "0.0.3"
+
 
 from mushan import shell
 from mushan import audio
@@ -6,6 +6,7 @@ from mushan import nb
 from mushan import ml
 from mushan import dl
 from mushan import tool
+from mushan import log
 
 __all__ = [
     "__version__",
