@@ -1,6 +1,12 @@
+'''
+Date: 2022-08-11 14:40:52
+LastEditors: mushan wwd137669793@gmail.com
+LastEditTime: 2022-12-30 21:47:56
+FilePath: /mushan/mushan/dl/func.py
+'''
 import torch
 import os
-from varname import nameof
+from varname import argname
 
 
 def get_device():
@@ -42,5 +48,8 @@ def set_cuda(gpus=None):
         print("Current CUDA Devices: {}".format(torch.cuda.current_device()))
         print("Total Visible CUDA Device Count: {}".format(torch.cuda.device_count()))
     
-def printshape(var):
-    print(f"{nameof(var)}: {var.shape}")
\ No newline at end of file
+    
+def printShape(*args):
+    for i in range(len(args)):
+        assert isinstance(args[i], torch.Tensor)
+        print(f"{argname(f'args[{i}]')}.shape: {str(list(args[i].shape))}, {str(args[i].dtype)[6:]}")
\ No newline at end of file
